# maphub-client

## Usage

### CLI
Coming soon...

### Python package
```python 
from maphub import MapHubClient

client = MapHubClient(api_key="your-api-key")
response = client.get_map(map_id="...")
```
